#include "pattern.ih"

Pattern::Pattern(Pair const &pair)
:
    d_pair(pair)
{}
